// file      : examples/cxx/tree/hello/driver.cxx
// author    : Boris Kolpackov <boris@codesynthesis.com>
// copyright : not copyrighted - public domain

#include <memory>   // std::auto_ptr
#include <iostream>
#include <fstream>

#include "hello9.hxx"

using namespace std;

int
main (int argc, char* argv[])
{
  if (argc != 2)
  {
    cerr << "usage: " << argv[0] << " hello.xml" << endl;
    return 1;
  }

  try
  {
    auto_ptr<xplangml::XPlanAuszugType> Auszug (xplangml::XPlanAuszug (argv[1]));

    /* Loop for all features */
    for (gml::AbstractFeatureCollectionType::featureMember_const_iterator i (Auszug->featureMember().begin());
         i != Auszug->featureMember ().end ();
         ++i)
    {
      if (const xplangml::BP_PlanType* bplan = dynamic_cast<const xplangml::BP_PlanType*> (&i->_Feature()))
      {
         cout << "BP_Plan" << endl;

         for (xplangml::BP_PlanType::raeumlicherGeltungsbereich_const_iterator j (bplan->raeumlicherGeltungsbereich().begin());
              j != bplan->raeumlicherGeltungsbereich().end();
              ++j)
         {
            ::gml::SurfacePropertyType surf = *j;
            ::gml::AbstractSurfaceType absurf = surf._Surface();
            ::gml::AbstractGMLType ab = absurf;
            if (const gml::PolygonType* p = dynamic_cast<const gml::PolygonType*> (&absurf))
            {
               cout << "polygon" << endl;
            }
            else
            {
               cout << "no polygon" << endl;
            }
         }
      }
      else
      {
         cout << "Unknown" << endl;
      }
      cout << endl;
    }
  }
  catch (const xml_schema::exception& e)
  {
    cerr << e << endl;
    return 1;
  }
}
